==> seedsui-react-2.6.2.tgz: package/es/MenuTree/MenuTree.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

// require PrototypeArray.js
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Instance from './instance.js';

var MenuTree = (_temp = _class = function (_Component) {
  _inherits(MenuTree, _Component);

  function MenuTree(props) {
    _classCallCheck(this, MenuTree);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidUpdate = function (prevProps) {
      if (JSON.stringify(prevProps.list) !== JSON.stringify(_this.props.list)) {
        if (_this.props.list && _this.props.list.length) {
          _this.instance.setSelectedId(_this.props.selectedId);
          var list = Object.clone(_this.props.list);
          if (JSON.stringify(list).indexOf('"children"') === -1) {
            list = list.deepTree();
          }
          _this.instance.setData(list);
        } else {
          _this.instance.setData([]);
        }
      }
    };

    _this.componentDidMount = function () {
      if (_this.instance) return;
      var list = Object.clone(_this.props.list);
      if (JSON.stringify(list).indexOf('"children"') === -1) {
        list = list.deepTree();
      }
      var instance = new Instance(_this.$el, {
        data: list,
        selectedId: _this.props.selectedId,
        onClick: _this.onClick // (item, isActive, isExtend: true展开 | false收缩)
      });
      _this.instance = instance;
    };

    _this.onClick = function (s, item, isActived, isExtend) {
      // childrenCount
      var childrenCount = item.children && item.children.length ? item.children.length : 0;

      if (_this.props.onClick) _this.props.onClick(s, item, isActived, isExtend, childrenCount);
    };

    return _this;
  }
  /* list: [{
    id: '',
    caption: '',
    active: false,
    children
  }] */


  MenuTree.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        className = _props.className,
        selectedId = _props.selectedId,
        onClick = _props.onClick,
        list = _props.list,
        others = _objectWithoutProperties(_props, ['className', 'selectedId', 'onClick', 'list']);

    return React.createElement('ul', _extends({ ref: function ref(el) {
        _this2.$el = el;
      }, className: 'menutree' + (className ? ' ' + className : '') }, others));
  };

  return MenuTree;
}(Component), _class.defaultProps = {}, _temp);
export { MenuTree as default };
MenuTree.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  selectedId: PropTypes.string, // 默认选中项的id
  onClick: PropTypes.func,

  list: PropTypes.array } : {};

==> seedsui-react-3.0.4.tgz: package/es/MenuTree/MenuTree.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

// require PrototypeArray.js
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Instance from './instance.js';

var MenuTree = (_temp = _class = function (_Component) {
  _inherits(MenuTree, _Component);

  function MenuTree(props) {
    _classCallCheck(this, MenuTree);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidUpdate = function (prevProps) {
      if (JSON.stringify(prevProps.list) !== JSON.stringify(_this.props.list)) {
        if (_this.props.list && _this.props.list.length) {
          _this.instance.setSelectedId(_this.props.selectedId);
          var list = Object.clone(_this.props.list);
          if (JSON.stringify(list).indexOf('"children"') === -1) {
            list = list.deepTree();
          }
          _this.instance.setData(list);
        } else {
          _this.instance.setData([]);
        }
      }
    };

    _this.componentDidMount = function () {
      if (_this.instance) return;
      var list = Object.clone(_this.props.list);
      if (JSON.stringify(list).indexOf('"children"') === -1) {
        list = list.deepTree();
      }
      var instance = new Instance(_this.$el, {
        data: list,
        selectedId: _this.props.selectedId,
        onClick: _this.onClick // (item, isActive, isExtend: true展开 | false收缩)
      });
      _this.instance = instance;
    };

    _this.onClick = function (s, item, isActived, isExtend) {
      // childrenCount
      var childrenCount = item.children && item.children.length ? item.children.length : 0;

      if (_this.props.onClick) _this.props.onClick(s, item, isActived, isExtend, childrenCount);
    };

    return _this;
  }
  /* list: [{
    id: '',
    caption: '',
    active: false,
    children
  }] */


  MenuTree.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        selectedId = _props.selectedId,
        onClick = _props.onClick,
        list = _props.list,
        others = _objectWithoutProperties(_props, ['selectedId', 'onClick', 'list']);

    return React.createElement('ul', _extends({ ref: function ref(el) {
        _this2.$el = el;
      } }, others, { className: 'menutree' + (others.className ? ' ' + others.className : '') }));
  };

  return MenuTree;
}(Component), _class.defaultProps = {}, _temp);
export { MenuTree as default };
MenuTree.propTypes = process.env.NODE_ENV !== "production" ? {
  selectedId: PropTypes.string, // 默认选中项的id
  onClick: PropTypes.func,

  list: PropTypes.array } : {};
